@@ -127,9 +127,9 @@ class FlinkSQLOperationManager extends OperationManager("FlinkSQLOperationManage
 
     val op = new GetTables(
       session = session,
-      catalog = catalogName,
-      schema = schemaName,
-      tableName = tableName,
+      catalogNameOrEmpty = catalogName,
+      schemaNamePattern = schemaName,
+      tableNamePattern = tableName,
       tableTypes = tTypes)
 
     addOperation(op)
@@ -146,9 +146,14 @@ class FlinkSQLOperationManager extends OperationManager("FlinkSQLOperationManage
       schemaName: String,
       tableName: String,
       columnName: String): Operation = {
-    throw new UnsupportedOperationException(
-      "Unsupported Operation type GetColumns. You can execute " +
-        "DESCRIBE statement instead to get column infos.")
+    val op = new GetColumns(
+      session = session,
+      catalogNameOrEmpty = catalogName,
+      schemaNamePattern = schemaName,
+      tableNamePattern = tableName,
+      columnNamePattern = columnName)
+
+    addOperation(op)
   }
 
   override def newGetFunctionsOperation(
@@ -180,6 +185,13 @@ class FlinkSQLOperationManager extends OperationManager("FlinkSQLOperationManage
   }
 
   override def getQueryId(operation: Operation): String = {
-    throw KyuubiSQLException.featureNotSupported()
+    // return empty string instead of null if there's no query id
+    // otherwise there would be TTransportException
+    operation match {
+      case exec: ExecuteStatement => exec.jobId.map(_.toHexString).getOrElse("")
+      case _: PlanOnlyStatement => ""
+      case _ =>
+        throw new IllegalStateException(s"Unsupported Flink operation class $classOf[operation].")
+    }
   }
 }
