@@ -19,11 +19,13 @@ package org.apache.kyuubi.engine.flink.session
 
 import scala.util.control.NonFatal
 
+import org.apache.flink.runtime.util.EnvironmentInformation
 import org.apache.flink.table.client.gateway.SqlExecutionException
 import org.apache.flink.table.client.gateway.context.SessionContext
 import org.apache.flink.table.client.gateway.local.LocalExecutor
-import org.apache.hive.service.rpc.thrift.TProtocolVersion
+import org.apache.hive.service.rpc.thrift.{TGetInfoType, TGetInfoValue, TProtocolVersion}
 
+import org.apache.kyuubi.KyuubiSQLException
 import org.apache.kyuubi.engine.flink.FlinkEngineUtils
 import org.apache.kyuubi.session.{AbstractSession, SessionManager}
 
@@ -52,6 +54,14 @@ class FlinkSessionImpl(
   override def open(): Unit = {
     executor.openSession(handle.identifier.toString)
     normalizedConf.foreach {
+      case ("use:catalog", catalog) =>
+        val tableEnv = sessionContext.getExecutionContext.getTableEnvironment
+        try {
+          tableEnv.useCatalog(catalog)
+        } catch {
+          case NonFatal(e) =>
+            throw e
+        }
       case ("use:database", database) =>
         val tableEnv = sessionContext.getExecutionContext.getTableEnvironment
         try {
@@ -66,4 +76,13 @@ class FlinkSessionImpl(
     }
     super.open()
   }
+
+  override def getInfo(infoType: TGetInfoType): TGetInfoValue = withAcquireRelease() {
+    infoType match {
+      case TGetInfoType.CLI_SERVER_NAME | TGetInfoType.CLI_DBMS_NAME =>
+        TGetInfoValue.stringValue("Apache Flink")
+      case TGetInfoType.CLI_DBMS_VER => TGetInfoValue.stringValue(EnvironmentInformation.getVersion)
+      case _ => throw KyuubiSQLException(s"Unrecognized GetInfoType value: $infoType")
+    }
+  }
 }
