@@ -17,9 +17,10 @@
 
 package org.apache.kyuubi.engine.spark.session
 
-import org.apache.hive.service.rpc.thrift.TProtocolVersion
+import org.apache.hive.service.rpc.thrift.{TGetInfoType, TGetInfoValue, TProtocolVersion}
 import org.apache.spark.sql.{AnalysisException, SparkSession}
 
+import org.apache.kyuubi.KyuubiSQLException
 import org.apache.kyuubi.engine.spark.events.SessionEvent
 import org.apache.kyuubi.engine.spark.operation.SparkSQLOperationManager
 import org.apache.kyuubi.engine.spark.shim.SparkCatalogShim
@@ -48,10 +49,15 @@ class SparkSessionImpl(
 
   private val sessionEvent = SessionEvent(this)
 
-  def serverIpAddress(): String = serverIpAddress
-
   override def open(): Unit = {
     normalizedConf.foreach {
+      case ("use:catalog", catalog) =>
+        try {
+          SparkCatalogShim().setCurrentCatalog(spark, catalog)
+        } catch {
+          case e if e.getMessage.contains("Cannot find catalog plugin class for catalog") =>
+            warn(e.getMessage())
+        }
       case ("use:database", database) =>
         try {
           SparkCatalogShim().setCurrentDatabase(spark, database)
@@ -59,9 +65,6 @@ class SparkSessionImpl(
           case e
               if database == "default" && e.getMessage != null &&
                 e.getMessage.contains("not found") =>
-          // use:database is from hive so the catalog is always session catalog which must have
-          // default namespace `default`. But as spark support v2 catalog, catalog may not have
-          // default namespace. Here we do nothing for compatible both session and v2 catalog.
         }
       case (key, value) => setModifiableConfig(key, value)
     }
@@ -75,11 +78,24 @@ class SparkSessionImpl(
     super.runOperation(operation)
   }
 
+  override def getInfo(infoType: TGetInfoType): TGetInfoValue = withAcquireRelease() {
+    infoType match {
+      case TGetInfoType.CLI_SERVER_NAME | TGetInfoType.CLI_DBMS_NAME =>
+        TGetInfoValue.stringValue("Spark SQL")
+      case TGetInfoType.CLI_DBMS_VER => TGetInfoValue.stringValue(org.apache.spark.SPARK_VERSION)
+      case TGetInfoType.CLI_ODBC_KEYWORDS => TGetInfoValue.stringValue("Unimplemented")
+      case TGetInfoType.CLI_MAX_COLUMN_NAME_LEN |
+          TGetInfoType.CLI_MAX_SCHEMA_NAME_LEN |
+          TGetInfoType.CLI_MAX_TABLE_NAME_LEN => TGetInfoValue.lenValue(128)
+      case _ => throw KyuubiSQLException(s"Unrecognized GetInfoType value: $infoType")
+    }
+  }
+
   override def close(): Unit = {
     sessionEvent.endTime = System.currentTimeMillis()
     EventBus.post(sessionEvent)
     super.close()
-    spark.sessionState.catalog.getTempViewNames().foreach(spark.catalog.uncacheTable(_))
+    spark.sessionState.catalog.getTempViewNames().foreach(spark.catalog.uncacheTable)
     sessionManager.operationManager.asInstanceOf[SparkSQLOperationManager].closeILoop(handle)
   }
 }
