@@ -24,16 +24,20 @@ import org.apache.spark.sql.internal.SQLConf.ANSI_ENABLED
 import org.scalatest.time.SpanSugar.convertIntToGrainOfTime
 
 import org.apache.kyuubi.config.KyuubiConf._
+import org.apache.kyuubi.engine.spark.KyuubiSparkUtil.sparkMajorMinorVersion
 import org.apache.kyuubi.engine.spark.WithDiscoverySparkSQLEngine
+import org.apache.kyuubi.engine.spark.WithEmbeddedZookeeper
 import org.apache.kyuubi.service.ServiceState
 
-abstract class SparkSQLEngineDeregisterSuite extends WithDiscoverySparkSQLEngine {
+abstract class SparkSQLEngineDeregisterSuite
+  extends WithDiscoverySparkSQLEngine with WithEmbeddedZookeeper {
   protected val maxJobFailures: Int = 2
 
   override def withKyuubiConf: Map[String, String] = {
-    super.withKyuubiConf ++ Map(
-      ANSI_ENABLED.key -> "true",
-      ENGINE_DEREGISTER_JOB_MAX_FAILURES.key -> maxJobFailures.toString)
+    super.withKyuubiConf ++
+      zookeeperConf ++ Map(
+        ANSI_ENABLED.key -> "true",
+        ENGINE_DEREGISTER_JOB_MAX_FAILURES.key -> maxJobFailures.toString)
   }
 
   override val namespace: String = s"/kyuubi/deregister_test/${UUID.randomUUID().toString}"
@@ -56,28 +60,48 @@ abstract class SparkSQLEngineDeregisterSuite extends WithDiscoverySparkSQLEngine
 
 class SparkSQLEngineDeregisterExceptionSuite extends SparkSQLEngineDeregisterSuite {
   override def withKyuubiConf: Map[String, String] = {
-    super.withKyuubiConf ++ Map(ENGINE_DEREGISTER_EXCEPTION_CLASSES.key ->
-      classOf[ArithmeticException].getCanonicalName)
+    super.withKyuubiConf ++ Map(ENGINE_DEREGISTER_EXCEPTION_CLASSES.key -> {
+      sparkMajorMinorVersion match {
+        // see https://issues.apache.org/jira/browse/SPARK-35958
+        case (3, minor) if minor > 2 => "org.apache.spark.SparkArithmeticException"
+        case _ => classOf[ArithmeticException].getCanonicalName
+      }
+    })
+
   }
 }
 
 class SparkSQLEngineDeregisterMsgSuite extends SparkSQLEngineDeregisterSuite {
   override def withKyuubiConf: Map[String, String] = {
     super.withKyuubiConf ++ Map(ENGINE_DEREGISTER_EXCEPTION_MESSAGES.key ->
-      "to int causes overflow")
+      // see https://issues.apache.org/jira/browse/SPARK-38926
+      // Upper case SQL types in error messages
+      // see https://issues.apache.org/jira/browse/SPARK-39007
+      // Use double quotes for SQL configs in error messages
+      // see https://issues.apache.org/jira/browse/SPARK-39214
+      // Improve errors related to CAST
+      "overflow")
   }
 }
 
-class SparkSQLEngineDeregisterExceptionTTLSuite extends WithDiscoverySparkSQLEngine {
+class SparkSQLEngineDeregisterExceptionTTLSuite
+  extends WithDiscoverySparkSQLEngine with WithEmbeddedZookeeper {
   protected val maxJobFailures: Int = 2
   protected val deregisterExceptionTTL = 2000
 
   override def withKyuubiConf: Map[String, String] = {
-    super.withKyuubiConf ++ Map(
-      ANSI_ENABLED.key -> "true",
-      ENGINE_DEREGISTER_EXCEPTION_CLASSES.key -> classOf[ArithmeticException].getCanonicalName,
-      ENGINE_DEREGISTER_JOB_MAX_FAILURES.key -> maxJobFailures.toString,
-      ENGINE_DEREGISTER_EXCEPTION_TTL.key -> deregisterExceptionTTL.toString)
+    super.withKyuubiConf ++
+      zookeeperConf ++ Map(
+        ANSI_ENABLED.key -> "true",
+        ENGINE_DEREGISTER_EXCEPTION_CLASSES.key -> {
+          sparkMajorMinorVersion match {
+            // see https://issues.apache.org/jira/browse/SPARK-35958
+            case (3, minor) if minor > 2 => "org.apache.spark.SparkArithmeticException"
+            case _ => classOf[ArithmeticException].getCanonicalName
+          }
+        },
+        ENGINE_DEREGISTER_JOB_MAX_FAILURES.key -> maxJobFailures.toString,
+        ENGINE_DEREGISTER_EXCEPTION_TTL.key -> deregisterExceptionTTL.toString)
   }
 
   override val namespace: String = s"/kyuubi/deregister_test/${UUID.randomUUID().toString}"
