@@ -30,14 +30,16 @@ import org.apache.thrift.server.{ServerContext, TServerEventHandler}
 import org.apache.thrift.transport.TTransport
 
 import org.apache.kyuubi.{KyuubiSQLException, Logging, Utils}
-import org.apache.kyuubi.config.KyuubiConf.{FRONTEND_CONNECTION_URL_USE_HOSTNAME, FRONTEND_THRIFT_BINARY_BIND_HOST}
+import org.apache.kyuubi.Utils.stringifyException
+import org.apache.kyuubi.config.KyuubiConf.FRONTEND_CONNECTION_URL_USE_HOSTNAME
+import org.apache.kyuubi.config.KyuubiReservedKeys.KYUUBI_CLIENT_IP_KEY
 import org.apache.kyuubi.operation.{FetchOrientation, OperationHandle}
 import org.apache.kyuubi.service.authentication.KyuubiAuthenticationFactory
 import org.apache.kyuubi.session.SessionHandle
 import org.apache.kyuubi.util.{KyuubiHadoopUtils, NamedThreadFactory}
 
 /**
- * Apache Thrift based hive-service-prc base class
+ * Apache Thrift based hive-service-rpc base class
  *   1. http
  *   2. binary
  */
@@ -45,17 +47,20 @@ abstract class TFrontendService(name: String)
   extends AbstractFrontendService(name) with TCLIService.Iface with Runnable with Logging {
   import TFrontendService._
   private val started = new AtomicBoolean(false)
-  private lazy val hadoopConf: Configuration = KyuubiHadoopUtils.newHadoopConf(conf)
+  private lazy val _hadoopConf: Configuration = KyuubiHadoopUtils.newHadoopConf(conf)
   private lazy val serverThread = new NamedThreadFactory(getName, false).newThread(this)
-  private lazy val serverHost = conf.get(FRONTEND_THRIFT_BINARY_BIND_HOST)
 
+  protected def serverHost: Option[String]
   protected def portNum: Int
   protected lazy val serverAddr: InetAddress =
     serverHost.map(InetAddress.getByName).getOrElse(Utils.findLocalInetAddress)
   protected lazy val serverSocket = new ServerSocket(portNum, -1, serverAddr)
+  protected lazy val actualPort: Int = serverSocket.getLocalPort
   protected lazy val authFactory: KyuubiAuthenticationFactory =
     new KyuubiAuthenticationFactory(conf, isServer())
 
+  protected def hadoopConf: Configuration = _hadoopConf
+
   /**
    * Start the service itself(FE) and its composited (Discovery service, DS) in the order of:
    *   Start FE ->
@@ -110,15 +115,15 @@ abstract class TFrontendService(name: String)
     val host = serverHost match {
       case Some(h) => h // respect user's setting ahead
       case None if conf.get(FRONTEND_CONNECTION_URL_USE_HOSTNAME) =>
-        serverAddr.getHostName
+        serverAddr.getCanonicalHostName
       case None =>
         serverAddr.getHostAddress
     }
-    val actualPort = serverSocket.getLocalPort
+
     host + ":" + actualPort
   }
 
-  private def getProxyUser(
+  protected def getProxyUser(
       sessionConf: java.util.Map[String, String],
       ipAddress: String,
       realUser: String): String = {
@@ -131,7 +136,7 @@ abstract class TFrontendService(name: String)
     }
   }
 
-  private def getUserName(req: TOpenSessionReq): String = {
+  protected def getUserName(req: TOpenSessionReq): String = {
     val realUser: String =
       ServiceUtils.getShortName(authFactory.getRemoteUser.getOrElse(req.getUsername))
     if (req.getConfiguration == null) {
@@ -140,6 +145,9 @@ abstract class TFrontendService(name: String)
       getProxyUser(req.getConfiguration, authFactory.getIpAddress.orNull, realUser)
     }
   }
+  protected def getIpAddress: String = {
+    authFactory.getIpAddress.orNull
+  }
 
   private def getMinVersion(versions: TProtocolVersion*): TProtocolVersion = {
     versions.minBy(_.getValue)
@@ -150,8 +158,8 @@ abstract class TFrontendService(name: String)
     val protocol = getMinVersion(SERVER_VERSION, req.getClient_protocol)
     res.setServerProtocolVersion(protocol)
     val userName = getUserName(req)
-    val ipAddress = authFactory.getIpAddress.orNull
-    val configuration =
+    val ipAddress = getIpAddress
+    val configuration = Map(KYUUBI_CLIENT_IP_KEY -> ipAddress) ++
       Option(req.getConfiguration).map(_.asScala.toMap).getOrElse(Map.empty[String, String])
     val sessionHandle = be.openSession(
       protocol,
@@ -230,7 +238,9 @@ abstract class TFrontendService(name: String)
         confOverlay.asScala.toMap,
         runAsync,
         queryTimeout)
-      resp.setOperationHandle(operationHandle.toTOperationHandle)
+      val tOperationHandle = operationHandle.toTOperationHandle
+      tOperationHandle.setOperationType(TOperationType.EXECUTE_STATEMENT)
+      resp.setOperationHandle(tOperationHandle)
       resp.setStatus(OK_STATUS)
     } catch {
       case e: Exception =>
@@ -245,7 +255,9 @@ abstract class TFrontendService(name: String)
     val resp = new TGetTypeInfoResp
     try {
       val operationHandle = be.getTypeInfo(SessionHandle(req.getSessionHandle))
-      resp.setOperationHandle(operationHandle.toTOperationHandle)
+      val tOperationHandle = operationHandle.toTOperationHandle
+      tOperationHandle.setOperationType(TOperationType.GET_TYPE_INFO)
+      resp.setOperationHandle(tOperationHandle)
       resp.setStatus(OK_STATUS)
     } catch {
       case e: Exception =>
@@ -260,7 +272,9 @@ abstract class TFrontendService(name: String)
     val resp = new TGetCatalogsResp
     try {
       val opHandle = be.getCatalogs(SessionHandle(req.getSessionHandle))
-      resp.setOperationHandle(opHandle.toTOperationHandle)
+      val tOperationHandle = opHandle.toTOperationHandle
+      tOperationHandle.setOperationType(TOperationType.GET_CATALOGS)
+      resp.setOperationHandle(tOperationHandle)
       resp.setStatus(OK_STATUS)
     } catch {
       case e: Exception =>
@@ -278,7 +292,9 @@ abstract class TFrontendService(name: String)
         SessionHandle(req.getSessionHandle),
         req.getCatalogName,
         req.getSchemaName)
-      resp.setOperationHandle(opHandle.toTOperationHandle)
+      val tOperationHandle = opHandle.toTOperationHandle
+      tOperationHandle.setOperationType(TOperationType.GET_SCHEMAS)
+      resp.setOperationHandle(tOperationHandle)
       resp.setStatus(OK_STATUS)
     } catch {
       case e: Exception =>
@@ -298,7 +314,9 @@ abstract class TFrontendService(name: String)
       val table = req.getTableName
       val tableTypes = req.getTableTypes
       val opHandle = be.getTables(sessionHandle, catalog, schema, table, tableTypes)
-      resp.setOperationHandle(opHandle.toTOperationHandle)
+      val tOperationHandle = opHandle.toTOperationHandle
+      tOperationHandle.setOperationType(TOperationType.GET_TABLES)
+      resp.setOperationHandle(tOperationHandle)
       resp.setStatus(OK_STATUS)
     } catch {
       case e: Exception =>
@@ -313,7 +331,9 @@ abstract class TFrontendService(name: String)
     val resp = new TGetTableTypesResp
     try {
       val opHandle = be.getTableTypes(SessionHandle(req.getSessionHandle))
-      resp.setOperationHandle(opHandle.toTOperationHandle)
+      val tOperationHandle = opHandle.toTOperationHandle
+      tOperationHandle.setOperationType(TOperationType.GET_TABLE_TYPES)
+      resp.setOperationHandle(tOperationHandle)
       resp.setStatus(OK_STATUS)
     } catch {
       case e: Exception =>
@@ -333,7 +353,9 @@ abstract class TFrontendService(name: String)
       val table = req.getTableName
       val col = req.getColumnName
       val opHandle = be.getColumns(sessionHandle, catalog, schema, table, col)
-      resp.setOperationHandle(opHandle.toTOperationHandle)
+      val tOperationHandle = opHandle.toTOperationHandle
+      tOperationHandle.setOperationType(TOperationType.GET_COLUMNS)
+      resp.setOperationHandle(tOperationHandle)
       resp.setStatus(OK_STATUS)
     } catch {
       case e: Exception =>
@@ -352,7 +374,9 @@ abstract class TFrontendService(name: String)
       val schema = req.getSchemaName
       val func = req.getFunctionName
       val opHandle = be.getFunctions(sessionHandle, catalog, schema, func)
-      resp.setOperationHandle(opHandle.toTOperationHandle)
+      val tOperationHandle = opHandle.toTOperationHandle
+      tOperationHandle.setOperationType(TOperationType.GET_FUNCTIONS)
+      resp.setOperationHandle(tOperationHandle)
       resp.setStatus(OK_STATUS)
     } catch {
       case e: Exception =>
@@ -365,16 +389,52 @@ abstract class TFrontendService(name: String)
   override def GetPrimaryKeys(req: TGetPrimaryKeysReq): TGetPrimaryKeysResp = {
     debug(req.toString)
     val resp = new TGetPrimaryKeysResp
-    val errStatus = KyuubiSQLException.featureNotSupported().toTStatus
-    resp.setStatus(errStatus)
+    try {
+      val sessionHandle = SessionHandle(req.getSessionHandle)
+      val catalog = req.getCatalogName
+      val schema = req.getSchemaName
+      val table = req.getTableName
+      val opHandle = be.getPrimaryKeys(sessionHandle, catalog, schema, table)
+      val tOperationHandle = opHandle.toTOperationHandle
+      tOperationHandle.setOperationType(TOperationType.GET_FUNCTIONS)
+      resp.setOperationHandle(tOperationHandle)
+      resp.setStatus(OK_STATUS)
+    } catch {
+      case e: Exception =>
+        error("Error getting primary keys: ", e)
+        resp.setStatus(KyuubiSQLException.toTStatus(e))
+    }
     resp
   }
 
   override def GetCrossReference(req: TGetCrossReferenceReq): TGetCrossReferenceResp = {
     debug(req.toString)
     val resp = new TGetCrossReferenceResp
-    val errStatus = KyuubiSQLException.featureNotSupported().toTStatus
-    resp.setStatus(errStatus)
+    try {
+      val sessionHandle = SessionHandle(req.getSessionHandle)
+      val primaryCatalog = req.getParentCatalogName
+      val primarySchema = req.getParentSchemaName
+      val primaryTable = req.getParentTableName
+      val foreignCatalog = req.getForeignCatalogName
+      val foreignSchema = req.getForeignSchemaName
+      val foreignTable = req.getForeignTableName
+      val opHandle = be.getCrossReference(
+        sessionHandle,
+        primaryCatalog,
+        primarySchema,
+        primaryTable,
+        foreignCatalog,
+        foreignSchema,
+        foreignTable)
+      val tOperationHandle = opHandle.toTOperationHandle
+      tOperationHandle.setOperationType(TOperationType.GET_FUNCTIONS)
+      resp.setOperationHandle(tOperationHandle)
+      resp.setStatus(OK_STATUS)
+    } catch {
+      case e: Exception =>
+        error("Error getting primary keys: ", e)
+        resp.setStatus(KyuubiSQLException.toTStatus(e))
+    }
     resp
   }
 
@@ -391,7 +451,10 @@ abstract class TFrontendService(name: String)
       operationStatus.exception.foreach { e =>
         resp.setSqlState(e.getSQLState)
         resp.setErrorCode(e.getErrorCode)
-        resp.setErrorMessage(e.getMessage)
+        resp.setErrorMessage(stringifyException(e))
+      }
+      operationStatus.operationProgressUpdate.foreach { p =>
+        resp.setProgressUpdateResponse(p)
       }
       resp.setStatus(OK_STATUS)
     } catch {
@@ -466,7 +529,7 @@ abstract class TFrontendService(name: String)
     resp
   }
 
-  private def notSupportTokenErrorStatus = {
+  protected def notSupportTokenErrorStatus = {
     val errorStatus = new TStatus(TStatusCode.ERROR_STATUS)
     errorStatus.setErrorMessage("Delegation token is not supported")
     errorStatus
@@ -489,20 +552,37 @@ abstract class TFrontendService(name: String)
   override def RenewDelegationToken(req: TRenewDelegationTokenReq): TRenewDelegationTokenResp = {
     debug(req.toString)
     val resp = new TRenewDelegationTokenResp
-    resp.setStatus(notSupportTokenErrorStatus)
+    resp.setStatus(OK_STATUS)
     resp
   }
 
   override def GetQueryId(req: TGetQueryIdReq): TGetQueryIdResp = {
     debug(req.toString)
     val resp = new TGetQueryIdResp
+    val queryId = be.getQueryId(OperationHandle(req.getOperationHandle))
+    resp.setQueryId(queryId)
     resp
   }
 
   override def SetClientInfo(req: TSetClientInfoReq): TSetClientInfoResp = {
     debug(req.toString)
     val resp = new TSetClientInfoResp
-    resp.setStatus(KyuubiSQLException.featureNotSupported().toTStatus)
+    if (req.isSetConfiguration) {
+      val sessionHandle = SessionHandle(req.getSessionHandle)
+      val stringBuilder = new StringBuilder("Client information for ")
+        .append(sessionHandle)
+        .append(": ")
+      val entries = req.getConfiguration.entrySet.asScala.toSeq
+      entries.headOption.foreach(e => {
+        stringBuilder.append(e.getKey).append(" = ").append(e.getValue)
+      })
+      entries.tail.foreach { e =>
+        stringBuilder.append(", ")
+        stringBuilder.append(e.getKey).append(" = ").append(e.getValue)
+      }
+      info(stringBuilder.toString())
+    }
+    resp.setStatus(OK_STATUS)
     resp
   }
 
@@ -544,7 +624,7 @@ private[kyuubi] object TFrontendService {
 
   final val CURRENT_SERVER_CONTEXT = new ThreadLocal[FeServiceServerContext]()
 
-  final val SERVER_VERSION = TProtocolVersion.HIVE_CLI_SERVICE_PROTOCOL_V10
+  final val SERVER_VERSION = TProtocolVersion.values.max
 
   class FeServiceServerContext extends ServerContext {
     private var sessionHandle: SessionHandle = _
