@@ -22,6 +22,7 @@ import java.nio.file.{Files, Paths}
 import java.util.concurrent.{ConcurrentHashMap, Future, ThreadPoolExecutor, TimeUnit}
 
 import scala.collection.JavaConverters._
+import scala.concurrent.duration.Duration
 
 import org.apache.hive.service.rpc.thrift.TProtocolVersion
 
@@ -49,10 +50,14 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
 
   private def initOperationLogRootDir(): Unit = {
     try {
-      _operationLogRoot.foreach { logRoot =>
-        val rootPath = Paths.get(logRoot)
-        Files.createDirectories(rootPath)
-      }
+      val logRoot =
+        if (isServer) {
+          conf.get(SERVER_OPERATION_LOG_DIR_ROOT)
+        } else {
+          conf.get(ENGINE_OPERATION_LOG_DIR_ROOT)
+        }
+      val logPath = Files.createDirectories(Utils.getAbsolutePathFromWork(logRoot))
+      _operationLogRoot = Some(logPath.toString)
     } catch {
       case e: IOException =>
         error(s"Failed to initialize operation log root directory: ${_operationLogRoot}", e)
@@ -76,12 +81,39 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
 
   def operationManager: OperationManager
 
+  protected def createSession(
+      protocol: TProtocolVersion,
+      user: String,
+      password: String,
+      ipAddress: String,
+      conf: Map[String, String]): Session
+
   def openSession(
       protocol: TProtocolVersion,
       user: String,
       password: String,
       ipAddress: String,
-      conf: Map[String, String]): SessionHandle
+      conf: Map[String, String]): SessionHandle = {
+    info(s"Opening session for $user@$ipAddress")
+    val session = createSession(protocol, user, password, ipAddress, conf)
+    try {
+      val handle = session.handle
+      session.open()
+      setSession(handle, session)
+      info(s"$user's session with $handle${session.name.map("/" + _).getOrElse("")} is opened," +
+        s" current opening sessions $getOpenSessionCount")
+      handle
+    } catch {
+      case e: Exception =>
+        try {
+          session.close()
+        } catch {
+          case t: Throwable =>
+            warn(s"Error closing session for $user client ip: $ipAddress", t)
+        }
+        throw KyuubiSQLException(e)
+    }
+  }
 
   def closeSession(sessionHandle: SessionHandle): Unit = {
     _latestLogoutTime = System.currentTimeMillis()
@@ -89,7 +121,8 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
     if (session == null) {
       throw KyuubiSQLException(s"Invalid $sessionHandle")
     }
-    info(s"$sessionHandle is closed, current opening sessions $getOpenSessionCount")
+    info(s"$sessionHandle${session.name.map("/" + _).getOrElse("")} is closed," +
+      s" current opening sessions $getOpenSessionCount")
     try {
       session.close()
     } finally {
@@ -109,12 +142,12 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
     })
   }
 
+  def getSessionOption(sessionHandle: SessionHandle): Option[Session] = {
+    Option(handleToSession.get(sessionHandle))
+  }
+
   def getSession(sessionHandle: SessionHandle): Session = {
-    val session = handleToSession.get(sessionHandle)
-    if (session == null) {
-      throw KyuubiSQLException(s"Invalid $sessionHandle")
-    }
-    session
+    getSessionOption(sessionHandle).getOrElse(throw KyuubiSQLException(s"Invalid $sessionHandle"))
   }
 
   final protected def setSession(sessionHandle: SessionHandle, session: Session): Unit = {
@@ -123,9 +156,7 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
 
   def getOpenSessionCount: Int = handleToSession.size()
 
-  def getSessionList(): ConcurrentHashMap[SessionHandle, Session] = {
-    handleToSession
-  }
+  def allSessions(): Iterable[Session] = handleToSession.values().asScala
 
   def getExecPoolSize: Int = {
     assert(execPool != null)
@@ -139,10 +170,13 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
 
   private var _confRestrictList: Set[String] = _
   private var _confIgnoreList: Set[String] = _
+  private var _batchConfIgnoreList: Set[String] = _
   private lazy val _confRestrictMatchList: Set[String] =
     _confRestrictList.filter(_.endsWith(".*")).map(_.stripSuffix(".*"))
   private lazy val _confIgnoreMatchList: Set[String] =
     _confIgnoreList.filter(_.endsWith(".*")).map(_.stripSuffix(".*"))
+  private lazy val _batchConfIgnoreMatchList: Set[String] =
+    _batchConfIgnoreList.filter(_.endsWith(".*")).map(_.stripSuffix(".*"))
 
   // strip prefix and validate whether if key is restricted, ignored or valid
   def validateKey(key: String, value: String): Option[(String, String)] = {
@@ -183,7 +217,22 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
     case (k, v) => validateKey(k, v)
   }
 
+  // validate whether if a batch key should be ignored
+  def validateBatchKey(key: String, value: String): Option[(String, String)] = {
+    if (_batchConfIgnoreMatchList.exists(key.startsWith(_)) || _batchConfIgnoreList.contains(key)) {
+      warn(s"$key is a ignored batch key according to the server-side configuration")
+      None
+    } else {
+      Some((key, value))
+    }
+  }
+
+  def validateBatchConf(config: Map[String, String]): Map[String, String] = config.flatMap {
+    case (k, v) => validateBatchKey(k, v)
+  }
+
   override def initialize(conf: KyuubiConf): Unit = synchronized {
+    this.conf = conf
     addService(operationManager)
     initOperationLogRootDir()
 
@@ -209,6 +258,7 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
 
     _confRestrictList = conf.get(SESSION_CONF_RESTRICT_LIST).toSet
     _confIgnoreList = conf.get(SESSION_CONF_IGNORE_LIST).toSet
+    _batchConfIgnoreList = conf.get(BATCH_CONF_IGNORE_LIST).toSet
 
     execPool = ThreadUtils.newDaemonQueuedThreadPool(
       poolSize,
@@ -232,25 +282,9 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
       } else {
         conf.get(SERVER_EXEC_POOL_SHUTDOWN_TIMEOUT)
       }
-    timeoutChecker.shutdown()
-    try {
-      timeoutChecker.awaitTermination(shutdownTimeout, TimeUnit.MILLISECONDS)
-    } catch {
-      case i: InterruptedException =>
-        warn(s"Exceeded to shutdown session timeout checker ", i)
-    }
 
-    if (execPool != null) {
-      execPool.shutdown()
-      try {
-        execPool.awaitTermination(shutdownTimeout, TimeUnit.MILLISECONDS)
-      } catch {
-        case e: InterruptedException =>
-          warn(
-            s"Exceeded timeout($shutdownTimeout ms) to wait the exec-pool shutdown gracefully",
-            e)
-      }
-    }
+    ThreadUtils.shutdown(timeoutChecker, Duration(shutdownTimeout, TimeUnit.MILLISECONDS))
+    ThreadUtils.shutdown(execPool, Duration(shutdownTimeout, TimeUnit.MILLISECONDS))
   }
 
   private def startTimeoutChecker(): Unit = {
@@ -271,7 +305,7 @@ abstract class SessionManager(name: String) extends CompositeService(name) {
                   warn(s"Error closing idle session ${session.handle}", e)
               }
             } else {
-              session.closeExpiredOperations
+              session.closeExpiredOperations()
             }
           }
         }
