@@ -23,8 +23,13 @@ import java.nio.file.{Files, Paths}
 import java.security.PrivilegedExceptionAction
 import java.util.Properties
 
+import scala.collection.mutable.ArrayBuffer
+
 import org.apache.hadoop.security.UserGroupInformation
 
+import org.apache.kyuubi.config.KyuubiConf
+import org.apache.kyuubi.config.KyuubiConf.SERVER_SECRET_REDACTION_PATTERN
+
 class UtilsSuite extends KyuubiFunSuite {
 
   test("build information check") {
@@ -40,6 +45,8 @@ class UtilsSuite extends KyuubiFunSuite {
     assert(props.getProperty("kyuubi_spark_version") === SPARK_COMPILE_VERSION)
     assert(props.getProperty("kyuubi_hive_version") === HIVE_COMPILE_VERSION)
     assert(props.getProperty("kyuubi_hadoop_version") === HADOOP_COMPILE_VERSION)
+    assert(props.getProperty("kyuubi_flink_version") === FLINK_COMPILE_VERSION)
+    assert(props.getProperty("kyuubi_trino_version") === TRINO_COMPILE_VERSION)
     assert(props.getProperty("branch") === BRANCH)
     assert(props.getProperty("revision") === REVISION)
     assert(props.getProperty("user") === BUILD_USER)
@@ -109,19 +116,6 @@ class UtilsSuite extends KyuubiFunSuite {
       })
   }
 
-  test("version test") {
-    assert(Utils.majorVersion(KYUUBI_VERSION) ===
-      Utils.majorMinorVersion(KYUUBI_VERSION)._1)
-    assert(Utils.majorVersion(SPARK_COMPILE_VERSION) ===
-      Utils.majorMinorVersion(SPARK_COMPILE_VERSION)._1)
-    assert(Utils.majorVersion(HADOOP_COMPILE_VERSION) ===
-      Utils.majorMinorVersion(HADOOP_COMPILE_VERSION)._1)
-    assert(Utils.minorVersion(KYUUBI_VERSION) ===
-      Utils.majorMinorVersion(KYUUBI_VERSION)._2)
-    intercept[IllegalArgumentException](Utils.shortVersion("-" + KYUUBI_VERSION))
-    intercept[IllegalArgumentException](Utils.majorMinorVersion("-" + KYUUBI_VERSION))
-  }
-
   test("findLocalInetAddress") {
     val address = InetAddress.getLocalHost
     if (!address.isLoopbackAddress) {
@@ -140,4 +134,72 @@ class UtilsSuite extends KyuubiFunSuite {
     val path2 = "/tmp/path2"
     assert(Utils.getAbsolutePathFromWork(path2).toString === path2)
   }
+
+  test("test args parser") {
+    val args = Array[String]("--conf", "k1=v1", "--conf", " k2 = v2")
+    val conf = new KyuubiConf()
+    Utils.fromCommandLineArgs(args, conf)
+    assert(conf.getOption("k1").get == "v1")
+    assert(conf.getOption("k2").get == "v2")
+
+    val args1 = Array[String]("--conf", "k1=v1", "--conf")
+    val exception1 = intercept[IllegalArgumentException](Utils.fromCommandLineArgs(args1, conf))
+    assert(exception1.getMessage.contains("Illegal size of arguments"))
+
+    val args2 = Array[String]("--conf", "k1=v1", "--conf", "a")
+    val exception2 = intercept[IllegalArgumentException](Utils.fromCommandLineArgs(args2, conf))
+    assert(exception2.getMessage.contains("Illegal argument: a"))
+  }
+
+  test("redact sensitive information in command line args") {
+    val conf = new KyuubiConf()
+    conf.set(SERVER_SECRET_REDACTION_PATTERN, "(?i)secret|password".r)
+
+    val buffer = new ArrayBuffer[String]()
+    buffer += "main"
+    buffer += "--conf"
+    buffer += "kyuubi.my.password=sensitive_value"
+    buffer += "--conf"
+    buffer += "kyuubi.regular.property1=regular_value"
+    buffer += "--conf"
+    buffer += "kyuubi.my.secret=sensitive_value"
+    buffer += "--conf"
+    buffer += "kyuubi.regular.property2=regular_value"
+
+    val commands = buffer.toArray
+
+    // Redact sensitive information
+    val redactedCmdArgs = Utils.redactCommandLineArgs(conf, commands)
+
+    val expectBuffer = new ArrayBuffer[String]()
+    expectBuffer += "main"
+    expectBuffer += "--conf"
+    expectBuffer += "kyuubi.my.password=" + Utils.REDACTION_REPLACEMENT_TEXT
+    expectBuffer += "--conf"
+    expectBuffer += "kyuubi.regular.property1=regular_value"
+    expectBuffer += "--conf"
+    expectBuffer += "kyuubi.my.secret=" + Utils.REDACTION_REPLACEMENT_TEXT
+    expectBuffer += "--conf"
+    expectBuffer += "kyuubi.regular.property2=regular_value"
+
+    assert(expectBuffer.toArray === redactedCmdArgs)
+  }
+
+  test("redact sensitive information") {
+    val secretKeys = Some("my.password".r)
+    assert(Utils.redact(secretKeys, Seq(("kyuubi.my.password", "12345"))) ===
+      Seq(("kyuubi.my.password", Utils.REDACTION_REPLACEMENT_TEXT)))
+    assert(Utils.redact(secretKeys, Seq(("anything", "kyuubi.my.password=12345"))) ===
+      Seq(("anything", Utils.REDACTION_REPLACEMENT_TEXT)))
+    assert(Utils.redact(secretKeys, Seq((999, "kyuubi.my.password=12345"))) ===
+      Seq((999, Utils.REDACTION_REPLACEMENT_TEXT)))
+    // Do not redact when value type is not string
+    assert(Utils.redact(secretKeys, Seq(("my.password", 12345))) ===
+      Seq(("my.password", 12345)))
+  }
+
+  test("test isCommandAvailable") {
+    assert(Utils.isCommandAvailable("java"))
+    assertResult(false)(Utils.isCommandAvailable("un_exist_cmd"))
+  }
 }
