@@ -34,18 +34,37 @@ class NoopOperationManager extends OperationManager("noop") {
       confOverlay: Map[String, String],
       runAsync: Boolean,
       queryTimeout: Long): Operation = {
-    val operation =
-      new NoopOperation(OperationType.EXECUTE_STATEMENT, session, statement == invalid)
+    val operation = new NoopOperation(session, statement == invalid)
+    addOperation(operation)
+  }
+
+  override def newSetCurrentCatalogOperation(session: Session, catalog: String): Operation = {
+    val operation = new NoopOperation(session)
+    addOperation(operation)
+  }
+
+  override def newGetCurrentCatalogOperation(session: Session): Operation = {
+    val operation = new NoopOperation(session)
+    addOperation(operation)
+  }
+
+  override def newSetCurrentDatabaseOperation(session: Session, database: String): Operation = {
+    val operation = new NoopOperation(session)
+    addOperation(operation)
+  }
+
+  override def newGetCurrentDatabaseOperation(session: Session): Operation = {
+    val operation = new NoopOperation(session)
     addOperation(operation)
   }
 
   override def newGetTypeInfoOperation(session: Session): Operation = {
-    val operation = new NoopOperation(OperationType.GET_TYPE_INFO, session)
+    val operation = new NoopOperation(session)
     addOperation(operation)
   }
 
   override def newGetCatalogsOperation(session: Session): Operation = {
-    val operation = new NoopOperation(OperationType.GET_CATALOGS, session)
+    val operation = new NoopOperation(session)
     addOperation(operation)
   }
 
@@ -53,7 +72,7 @@ class NoopOperationManager extends OperationManager("noop") {
       session: Session,
       catalog: String,
       schema: String): Operation = {
-    val operation = new NoopOperation(OperationType.GET_SCHEMAS, session)
+    val operation = new NoopOperation(session)
     addOperation(operation)
   }
 
@@ -63,12 +82,12 @@ class NoopOperationManager extends OperationManager("noop") {
       schemaName: String,
       tableName: String,
       tableTypes: java.util.List[String]): Operation = {
-    val operation = new NoopOperation(OperationType.GET_TABLES, session, schemaName == invalid)
+    val operation = new NoopOperation(session, schemaName == invalid)
     addOperation(operation)
   }
 
   override def newGetTableTypesOperation(session: Session): Operation = {
-    val operation = new NoopOperation(OperationType.GET_TABLE_TYPES, session)
+    val operation = new NoopOperation(session)
     addOperation(operation)
   }
 
@@ -78,7 +97,7 @@ class NoopOperationManager extends OperationManager("noop") {
       schemaName: String,
       tableName: String,
       columnName: String): Operation = {
-    val operation = new NoopOperation(OperationType.GET_COLUMNS, session)
+    val operation = new NoopOperation(session)
     addOperation(operation)
   }
 
@@ -87,7 +106,30 @@ class NoopOperationManager extends OperationManager("noop") {
       catalogName: String,
       schemaName: String,
       functionName: String): Operation = {
-    val operation = new NoopOperation(OperationType.GET_FUNCTIONS, session)
+    val operation = new NoopOperation(session)
+    addOperation(operation)
+  }
+
+  override def newGetPrimaryKeysOperation(
+      session: Session,
+      catalogName: String,
+      schemaName: String,
+      tableName: String): Operation = {
+    val operation =
+      new NoopOperation(session, schemaName == invalid)
+    addOperation(operation)
+  }
+
+  override def newGetCrossReferenceOperation(
+      session: Session,
+      primaryCatalog: String,
+      primarySchema: String,
+      primaryTable: String,
+      foreignCatalog: String,
+      foreignSchema: String,
+      foreignTable: String): Operation = {
+    val operation =
+      new NoopOperation(session, primarySchema == invalid)
     addOperation(operation)
   }
 
@@ -102,4 +144,9 @@ class NoopOperationManager extends OperationManager("noop") {
     tRow.addToColumns(tColumn)
     tRow
   }
+
+  override def getQueryId(operation: Operation): String = {
+    val queryId = "noop_query_id"
+    queryId
+  }
 }
