@@ -490,12 +490,14 @@ class ControlCliArgumentsSuite extends KyuubiFunSuite with TestPrematureExit {
       "--hostUrl",
       "https://kyuubi.test.com",
       "--conf",
-      s"${CtlConf.CTL_REST_CLIENT_CONNECT_TIMEOUT.key}=5000")
+      s"${CtlConf.CTL_REST_CLIENT_CONNECT_TIMEOUT.key}=5000",
+      "--conf",
+      s"${CtlConf.CTL_REST_CLIENT_REQUEST_MAX_ATTEMPTS.key}=1")
     val opArgs = new ControlCliArguments(args)
     withKyuubiRestClient(opArgs.cliConfig, null, opArgs.command.conf) { kyuubiRestClient =>
       assert(kyuubiRestClient.getConf.getConnectTimeout == 5000)
       assert(kyuubiRestClient.getConf.getSocketTimeout == 120000)
-      assert(kyuubiRestClient.getConf.getMaxAttempts == 3)
+      assert(kyuubiRestClient.getConf.getMaxAttempts == 1)
       assert(kyuubiRestClient.getConf.getAttemptWaitTime == 3000)
     }
   }
