@@ -27,13 +27,13 @@ object MetricsConf {
   private def buildConf(key: String): ConfigBuilder = KyuubiConf.buildConf(key)
 
   val METRICS_ENABLED: ConfigEntry[Boolean] =
-    buildConf("metrics.enabled")
+    buildConf("kyuubi.metrics.enabled")
       .doc("Set to true to enable kyuubi metrics system")
       .version("1.2.0")
       .booleanConf
       .createWithDefault(true)
 
-  val METRICS_REPORTERS: ConfigEntry[Seq[String]] = buildConf("metrics.reporters")
+  val METRICS_REPORTERS: ConfigEntry[Seq[String]] = buildConf("kyuubi.metrics.reporters")
     .doc("A comma separated list for all metrics reporters" +
       "<ul>" +
       " <li>CONSOLE - ConsoleReporter which outputs measurements to CONSOLE periodically.</li>" +
@@ -51,39 +51,39 @@ object MetricsConf {
       s"the reporter type should be one or more of ${ReporterType.values.mkString(",")}")
     .createWithDefault(Seq(JSON.toString))
 
-  val METRICS_CONSOLE_INTERVAL: ConfigEntry[Long] = buildConf("metrics.console.interval")
+  val METRICS_CONSOLE_INTERVAL: ConfigEntry[Long] = buildConf("kyuubi.metrics.console.interval")
     .doc("How often should report metrics to console")
     .version("1.2.0")
     .timeConf
     .createWithDefault(Duration.ofSeconds(5).toMillis)
 
-  val METRICS_JSON_LOCATION: ConfigEntry[String] = buildConf("metrics.json.location")
+  val METRICS_JSON_LOCATION: ConfigEntry[String] = buildConf("kyuubi.metrics.json.location")
     .doc("Where the json metrics file located")
     .version("1.2.0")
     .stringConf
     .createWithDefault("metrics")
 
-  val METRICS_JSON_INTERVAL: ConfigEntry[Long] = buildConf("metrics.json.interval")
+  val METRICS_JSON_INTERVAL: ConfigEntry[Long] = buildConf("kyuubi.metrics.json.interval")
     .doc("How often should report metrics to json file")
     .version("1.2.0")
     .timeConf
     .createWithDefault(Duration.ofSeconds(5).toMillis)
 
-  val METRICS_PROMETHEUS_PORT: ConfigEntry[Int] = buildConf("metrics.prometheus.port")
+  val METRICS_PROMETHEUS_PORT: ConfigEntry[Int] = buildConf("kyuubi.metrics.prometheus.port")
     .doc("Prometheus metrics HTTP server port")
     .version("1.2.0")
     .intConf
     .checkValue(p => p == 0 || (p > 1024 && p < 65535), "Invalid Port number")
     .createWithDefault(10019)
 
-  val METRICS_PROMETHEUS_PATH: ConfigEntry[String] = buildConf("metrics.prometheus.path")
+  val METRICS_PROMETHEUS_PATH: ConfigEntry[String] = buildConf("kyuubi.metrics.prometheus.path")
     .doc("URI context path of prometheus metrics HTTP server")
     .version("1.2.0")
     .stringConf
     .checkValue(path => path.startsWith("/"), "Context path must start with '/'")
     .createWithDefault("/metrics")
 
-  val METRICS_SLF4J_INTERVAL: ConfigEntry[Long] = buildConf("metrics.slf4j.interval")
+  val METRICS_SLF4J_INTERVAL: ConfigEntry[Long] = buildConf("kyuubi.metrics.slf4j.interval")
     .doc("How often should report metrics to SLF4J logger")
     .version("1.2.0")
     .timeConf
