@@ -91,10 +91,14 @@ class SparkProcessBuilder(
       buffer += s"${convertConfigKey(k)}=$v"
     }
 
-    // iff the keytab is specified, PROXY_USER is not supported
-    if (!useKeytab()) {
-      buffer += PROXY_USER
-      buffer += proxyUser
+    // if the keytab is specified, PROXY_USER is not supported
+    tryKeytab() match {
+      case None =>
+        setSparkUserName(proxyUser, buffer)
+        buffer += PROXY_USER
+        buffer += proxyUser
+      case Some(name) =>
+        setSparkUserName(name, buffer)
     }
 
     mainResource.foreach { r => buffer += r }
@@ -104,26 +108,27 @@ class SparkProcessBuilder(
 
   override protected def module: String = "kyuubi-spark-sql-engine"
 
-  private def useKeytab(): Boolean = {
+  private def tryKeytab(): Option[String] = {
     val principal = conf.getOption(PRINCIPAL)
     val keytab = conf.getOption(KEYTAB)
     if (principal.isEmpty || keytab.isEmpty) {
-      false
+      None
     } else {
       try {
         val ugi = UserGroupInformation
           .loginUserFromKeytabAndReturnUGI(principal.get, keytab.get)
-        val keytabEnabled = ugi.getShortUserName == proxyUser
-        if (!keytabEnabled) {
+        if (ugi.getShortUserName != proxyUser) {
           warn(s"The session proxy user: $proxyUser is not same with " +
             s"spark principal: ${ugi.getShortUserName}, so we can't support use keytab. " +
             s"Fallback to use proxy user.")
+          None
+        } else {
+          Some(ugi.getShortUserName)
         }
-        keytabEnabled
       } catch {
         case e: IOException =>
           error(s"Failed to login for ${principal.get}", e)
-          false
+          None
       }
     }
   }
@@ -168,6 +173,17 @@ class SparkProcessBuilder(
 
   override def validateConf: Unit = Validator.validateConf(conf)
 
+  // For spark on kubernetes, spark pod using env SPARK_USER_NAME as current user
+  def setSparkUserName(userName: String, buffer: ArrayBuffer[String]): Unit = {
+    clusterManager().foreach { cm =>
+      if (cm.toUpperCase.startsWith("K8S")) {
+        buffer += CONF
+        buffer += s"spark.kubernetes.driverEnv.SPARK_USER_NAME=$userName"
+        buffer += CONF
+        buffer += s"spark.executorEnv.SPARK_USER_NAME=$userName"
+      }
+    }
+  }
 }
 
 object SparkProcessBuilder {
