@@ -19,13 +19,11 @@ package org.apache.kyuubi.operation
 
 import scala.collection.JavaConverters._
 
-import org.apache.hive.service.rpc.thrift.TGetOperationStatusResp
+import org.apache.hive.service.rpc.thrift.{TGetOperationStatusResp, TProtocolVersion}
 import org.apache.hive.service.rpc.thrift.TOperationState._
-import org.apache.thrift.TException
 
 import org.apache.kyuubi.KyuubiSQLException
-import org.apache.kyuubi.config.KyuubiConf
-import org.apache.kyuubi.events.{EventLogging, KyuubiOperationEvent}
+import org.apache.kyuubi.events.{EventBus, KyuubiOperationEvent}
 import org.apache.kyuubi.operation.FetchOrientation.FETCH_NEXT
 import org.apache.kyuubi.operation.OperationState.OperationState
 import org.apache.kyuubi.operation.log.OperationLog
@@ -37,8 +35,8 @@ class ExecuteStatement(
     confOverlay: Map[String, String],
     override val shouldRunAsync: Boolean,
     queryTimeout: Long)
-  extends KyuubiOperation(OperationType.EXECUTE_STATEMENT, session) {
-  EventLogging.onEvent(KyuubiOperationEvent(this))
+  extends KyuubiOperation(session) {
+  EventBus.post(KyuubiOperationEvent(this))
 
   final private val _operationLog: OperationLog =
     if (shouldRunAsync) {
@@ -47,10 +45,6 @@ class ExecuteStatement(
       null
     }
 
-  private val maxStatusPollOnFailure = {
-    session.sessionManager.getConf.get(KyuubiConf.OPERATION_STATUS_POLLING_MAX_ATTEMPTS)
-  }
-
   override def getOperationLog: Option[OperationLog] = Option(_operationLog)
 
   override def beforeRun(): Unit = {
@@ -77,43 +71,26 @@ class ExecuteStatement(
     try {
       setState(OperationState.RUNNING)
       var statusResp: TGetOperationStatusResp = null
-      var currentAttempts = 0
-
-      def fetchOperationStatusWithRetry(): Unit = {
-        try {
-          statusResp = client.getOperationStatus(_remoteOpHandle)
-          currentAttempts = 0 // reset attempts whenever get touch with engine again
-        } catch {
-          case e: TException if currentAttempts >= maxStatusPollOnFailure =>
-            error(
-              s"Failed to get ${session.user}'s query[$getHandle] status after" +
-                s" $maxStatusPollOnFailure times, aborting",
-              e)
-            throw e
-          case e: TException =>
-            currentAttempts += 1
-            warn(
-              s"Failed to get ${session.user}'s query[$getHandle] status" +
-                s" ($currentAttempts / $maxStatusPollOnFailure)",
-              e)
-            Thread.sleep(100)
-        }
-      }
 
       // initialize operation status
-      while (statusResp == null) { fetchOperationStatusWithRetry() }
+      while (statusResp == null) {
+        statusResp = client.getOperationStatus(_remoteOpHandle)
+      }
 
       var isComplete = false
       while (!isComplete) {
         fetchQueryLog()
         verifyTStatus(statusResp.getStatus)
+        if (statusResp.getProgressUpdateResponse != null) {
+          setOperationJobProgress(statusResp.getProgressUpdateResponse)
+        }
         val remoteState = statusResp.getOperationState
         info(s"Query[$statementId] in ${remoteState.name()}")
         isComplete = true
         remoteState match {
           case INITIALIZED_STATE | PENDING_STATE | RUNNING_STATE =>
             isComplete = false
-            fetchOperationStatusWithRetry()
+            statusResp = client.getOperationStatus(_remoteOpHandle)
 
           case FINISHED_STATE =>
             setState(OperationState.FINISHED)
@@ -124,6 +101,17 @@ class ExecuteStatement(
           case CANCELED_STATE =>
             setState(OperationState.CANCELED)
 
+          case TIMEDOUT_STATE
+              // Clients less than version 2.1 have no HIVE-4924 Patch,
+              // no queryTimeout parameter and no TIMEOUT status.
+              // When the server enables kyuubi.operation.query.timeout,
+              // this will cause the client of the lower version to get stuck.
+              // Check thrift protocol version <= HIVE_CLI_SERVICE_PROTOCOL_V8(Hive 2.1.0),
+              // convert TIMEDOUT_STATE to CANCELED.
+              if getProtocolVersion.getValue <=
+                TProtocolVersion.HIVE_CLI_SERVICE_PROTOCOL_V8.getValue =>
+            setState(OperationState.CANCELED)
+
           case TIMEDOUT_STATE =>
             setState(OperationState.TIMEOUT)
 
@@ -174,6 +162,6 @@ class ExecuteStatement(
 
   override def setState(newState: OperationState): Unit = {
     super.setState(newState)
-    EventLogging.onEvent(KyuubiOperationEvent(this))
+    EventBus.post(KyuubiOperationEvent(this))
   }
 }
