@@ -18,12 +18,10 @@
 package org.apache.kyuubi.operation
 
 import org.apache.kyuubi.operation.log.OperationLog
-import org.apache.kyuubi.session.{KyuubiSessionImpl, KyuubiSessionManager}
+import org.apache.kyuubi.session.KyuubiSessionImpl
 
 class LaunchEngine(session: KyuubiSessionImpl, override val shouldRunAsync: Boolean)
-  extends KyuubiOperation(OperationType.UNKNOWN_OPERATION, session) {
-
-  override def statement: String = "LAUNCH_ENGINE"
+  extends KyuubiOperation(session) {
 
   private lazy val _operationLog: OperationLog =
     if (shouldRunAsync) {
@@ -44,12 +42,11 @@ class LaunchEngine(session: KyuubiSessionImpl, override val shouldRunAsync: Bool
     OperationLog.removeCurrentOperationLog()
   }
 
-  override protected def runInternal(): Unit = {
+  override protected def runInternal(): Unit = session.handleSessionException {
     val asyncOperation: Runnable = () => {
       setState(OperationState.RUNNING)
       try {
         session.openEngineSession(getOperationLog)
-        renewEngineCredentials()
         setState(OperationState.FINISHED)
       } catch onError()
     }
@@ -60,18 +57,4 @@ class LaunchEngine(session: KyuubiSessionImpl, override val shouldRunAsync: Bool
 
     if (!shouldRunAsync) getBackgroundHandle.get()
   }
-
-  private def renewEngineCredentials(): Unit = {
-    val sessionManager = session.sessionManager.asInstanceOf[KyuubiSessionManager]
-    try {
-      sessionManager.credentialsManager.sendCredentialsIfNeeded(
-        session.handle.identifier.toString,
-        session.user,
-        client.sendCredentials,
-        true)
-    } catch {
-      case e: Exception =>
-        error(s"Failed to renew engine credentials when launching engine", e)
-    }
-  }
 }
