@@ -63,6 +63,7 @@ class KyuubiSessionImpl(
 
   // TODO: needs improve the hardcode
   optimizedConf.foreach {
+    case ("use:catalog", _) =>
     case ("use:database", _) =>
     case ("kyuubi.engine.pool.size.threshold", _) =>
     case (key, value) => sessionConf.set(key, value)
@@ -197,4 +198,15 @@ class KyuubiSessionImpl(
       MetricsSystem.tracing(_.decCount(MetricRegistry.name(CONN_OPEN, user)))
     }
   }
+
+  override def getInfo(infoType: TGetInfoType): TGetInfoValue = {
+    sessionConf.get(SERVER_INFO_PROVIDER) match {
+      case "SERVER" => super.getInfo(infoType)
+      case "ENGINE" => withAcquireRelease() {
+          waitForEngineLaunched()
+          client.getInfo(infoType).getInfoValue
+        }
+      case unknown => throw new IllegalArgumentException(s"Unknown server info provider $unknown")
+    }
+  }
 }
