@@ -17,7 +17,7 @@
 
 package org.apache.kyuubi.operation
 
-import java.sql.Statement
+import java.sql.{SQLException, Statement}
 
 import org.apache.kyuubi.WithKyuubiServer
 import org.apache.kyuubi.config.KyuubiConf
@@ -103,6 +103,31 @@ class PlanOnlyOperationSuite extends WithKyuubiServer with HiveJDBCTestHelper {
     }
   }
 
+  test("kyuubi #2565: Variable substitution should work in plan only mode") {
+    withSessionConf()(Map(KyuubiConf.OPERATION_PLAN_ONLY_MODE.key -> PARSE.toString))(Map.empty) {
+      withJdbcStatement() { statement =>
+        statement.executeQuery("set x = y")
+        val resultSet = statement.executeQuery("select '${x}'")
+        assert(resultSet.next())
+        resultSet.getString(1).contains("'Project [unresolvedalias(y, None)]")
+      }
+    }
+  }
+
+  test("kyuubi #3214: Plan only mode with an incorrect value") {
+    withSessionConf()(Map(KyuubiConf.OPERATION_PLAN_ONLY_MODE.key -> "parse"))(Map.empty) {
+      withJdbcStatement() { statement =>
+        statement.executeQuery(s"set ${KyuubiConf.OPERATION_PLAN_ONLY_MODE.key}=parser")
+        val e = intercept[SQLException](statement.executeQuery("select 1"))
+        assert(e.getMessage.contains("The operation mode UNKNOWN doesn't support"))
+        statement.executeQuery(s"set ${KyuubiConf.OPERATION_PLAN_ONLY_MODE.key}=parse")
+        val result = statement.executeQuery("select 1")
+        assert(result.next())
+        assert(result.getString(1).contains("Project [unresolvedalias(1, None)]"))
+      }
+    }
+  }
+
   private def getOperationPlanWithStatement(statement: Statement): String = {
     val resultSet = statement.executeQuery("select 1 where true")
     assert(resultSet.next())
